==> libdrumstick_2.0.0.orig.tar.gz: drumstick-2.0.0/utils/guiplayer/drumstick-guiplayer_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AboutClass</name>
    <message>
        <location filename="playerabout.ui" line="14"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="playerabout.ui" line="30"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Drumstick MIDI Player %VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2020, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program. If not, see &lt;/span&gt;&lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="playerabout.ui" line="57"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GUIPlayerClass</name>
    <message>
        <location filename="guiplayer.ui" line="14"/>
        <location filename="guiplayer.ui" line="25"/>
        <source>Drumstick MIDI Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="159"/>
        <source>Playback time and current levels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="200"/>
        <source>00:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="207"/>
        <source>Tempo:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="230"/>
        <source>Volume:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="244"/>
        <source>Pitch:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="257"/>
        <source>Pitch Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="260"/>
        <source>Pitch transpose between -12 and +12 semitones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="276"/>
        <source>Reset Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="279"/>
        <source>Reset Volume to 100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="299"/>
        <source>Volume Slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="327"/>
        <source>Playback progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="351"/>
        <source>File Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="364"/>
        <source>Currently loaded MIDI file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="385"/>
        <source>Tempo Slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="422"/>
        <source>Reset Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="425"/>
        <source>Reset Tempo to 100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="428"/>
        <source>tempo=100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="445"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="457"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="464"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="477"/>
        <source>Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="505"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="508"/>
        <source>Open a MIDI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="517"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="520"/>
        <source>Quit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="529"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="532"/>
        <source>Start playing the current MIDI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="550"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="553"/>
        <source>Pause the playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="565"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="568"/>
        <source>Stop the playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="580"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="583"/>
        <source>Show the about box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="592"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="595"/>
        <source>Show the about Qt dialog box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="604"/>
        <source>MIDI Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="607"/>
        <source>Select a connection for the MIDI output port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="618"/>
        <location filename="guiplayer.ui" line="621"/>
        <source>Show Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="624"/>
        <source>Show or hide the tool bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="635"/>
        <source>Show Status Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="638"/>
        <source>Show or hide the status bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> libdrumstick_2.5.0.orig.tar.gz: drumstick-2.5.0/utils/guiplayer/drumstick-guiplayer_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>About</name>
    <message>
        <location filename="playerabout.cpp" line="29"/>
        <source>Revision</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutClass</name>
    <message>
        <location filename="playerabout.ui" line="14"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="playerabout.ui" line="30"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Drumstick ALSA MIDI Player %VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2021, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program. If not, see &lt;/span&gt;&lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Drumstick ALSA MIDI Player %VERSION%&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2021, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program. If not, see &lt;/span&gt;&lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;http://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="playerabout.ui" line="57"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GUIPlayerClass</name>
    <message>
        <location filename="guiplayer.ui" line="14"/>
        <source>Drumstick ALSA MIDI Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="25"/>
        <source>Drumstick MIDI Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="159"/>
        <source>Playback time and current levels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="200"/>
        <source>00:00:00</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="207"/>
        <source>Tempo:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="230"/>
        <source>Volume:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="244"/>
        <source>Pitch:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="257"/>
        <source>Pitch Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="260"/>
        <source>Pitch transpose between -12 and +12 semitones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="276"/>
        <source>Reset Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="279"/>
        <source>Reset Volume to 100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="299"/>
        <source>Volume Slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="327"/>
        <source>Playback progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="351"/>
        <source>File Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="364"/>
        <source>Currently loaded MIDI file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="385"/>
        <source>Tempo Slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="422"/>
        <source>Reset Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="425"/>
        <source>Reset Tempo to 100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="428"/>
        <source>tempo=100%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="445"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="457"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="464"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="477"/>
        <source>Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="505"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="508"/>
        <source>Open a MIDI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="517"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="520"/>
        <source>Quit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="529"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="532"/>
        <source>Start playing the current MIDI file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="550"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="553"/>
        <source>Pause the playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="565"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="568"/>
        <source>Stop the playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="580"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="583"/>
        <source>Show the about box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="592"/>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="595"/>
        <source>Show the about Qt dialog box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="604"/>
        <source>MIDI Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="607"/>
        <source>Select a connection for the MIDI output port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="618"/>
        <location filename="guiplayer.ui" line="621"/>
        <source>Show Tool Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="624"/>
        <source>Show or hide the tool bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="635"/>
        <source>Show Status Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="guiplayer.ui" line="638"/>
        <source>Show or hide the status bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
